@@ -86,8 +86,8 @@ sub prepare {
             next unless defined($c) && $c->visible;
             $self->prepare($c);
         }
-    } else {
-        $comp->prepared(1);
+    # } else {
+    #     $comp->prepared(1);
     }
 }
 
